# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]


### [1.73.0.0] - 2022-12-07

### Updated

- Synapse to 1.73.0

### [1.72.0.0] - 2022-11-22

### Updated

- Synapse to 1.72.0

### [1.71.0.0] - 2022-11-09

### Updated

- Synapse to 1.71.0

### [1.70.1.0] - 2022-11-09

### Updated

- Synapse to 1.70.1

### [1.70.0.0] - 2022-11-09

### Updated

- Synapse to 1.70.0

### [1.69.0.0] - 2022-11-09

### Updated

- Synapse to 1.69.0

### [1.68.0.0] - 2022-11-09

### Updated

- Synapse to 1.68.0

### [1.67.0.0] - 2022-11-09

### Updated

- Synapse to 1.67.0

### [1.66.0.0] - 2022-11-09

### Updated

- Synapse to 1.66.0

### [1.65.0.0] - 2022-11-09

### Updated

- Synapse to 1.65.0

### Fixed

- Location of github action workflow file `build.yml`
- Fix robustness for matrix-synapse name and packages changes and rebuilding in the same path (updater script)

[unreleased]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.73.0.0...HEAD
[1.73.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.72.0.0...v1.73.0.0
[1.72.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.71.0.0...v1.72.0.0
[1.71.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.1.0...v1.71.0.0
[1.70.1.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.0.0...v1.70.1.0
[1.70.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.69.0.0...v1.70.0.0
[1.69.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.68.0.0...v1.69.0.0
[1.68.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.67.0.0...v1.68.0.0
[1.67.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.66.0.0...v1.67.0.0
[1.66.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0...v1.66.0.0
[1.65.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0
